package com.hd.mail.service;

import java.io.File;

import javax.mail.MessagingException;
import javax.mail.internet.MimeMessage;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.FileSystemResource;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.stereotype.Service;

/**
 * 发送邮件
 */
@Service
public class MailService {
	// 直接读取application.properties配置文件
	@Value("${spring.mail.username}")
	private String from;
	@Autowired private JavaMailSender mailSender;
	
	
	/**
	 * 发送内嵌图片的邮件
	 * @param to
	 * @param subject
	 * @param content
	 * @param picId
	 * @param picPath
	 * @throws MessagingException
	 */
	public void sendMailInLine(String to,String subject,String content,String picId,String picPath) throws MessagingException{
		MimeMessage mimeMessage = mailSender.createMimeMessage();
		MimeMessageHelper helper = new MimeMessageHelper(mimeMessage,true);
		
		helper.setTo(to);
		helper.setSubject(subject);
		helper.setText(content, true);
		
		// 设置图片
		FileSystemResource file = new FileSystemResource(new File(picPath));
		helper.addInline(picId, file);
		
		helper.setFrom(from);
		mailSender.send(mimeMessage);
	}
	
	/**
	 * 发送带附件的邮件
	 * @param to
	 * @param subject
	 * @param content
	 * @param filePath
	 * @throws MessagingException
	 */
	public void sendMailAtt(String to,String subject,String content,String filePath) throws MessagingException{
		MimeMessage mimeMessage = mailSender.createMimeMessage();
		MimeMessageHelper helper = new MimeMessageHelper(mimeMessage,true);
		
		helper.setTo(to);
		helper.setSubject(subject);
		helper.setText(content, true);
		
		// 设置附件
		FileSystemResource file = new FileSystemResource(new File(filePath));
		String fname = file.getFilename();
		helper.addAttachment(fname, file);//附件可以添加多个
		
		helper.setFrom(from);
		mailSender.send(mimeMessage);
	}
	
	/**
	 * 发送HTML邮件
	 * @param to
	 * @param subject
	 * @param content
	 * @throws MessagingException
	 */
	public void sendMailHtml(String to,String subject,String content) throws MessagingException{
		MimeMessage mimeMessage = mailSender.createMimeMessage();
		MimeMessageHelper helper = new MimeMessageHelper(mimeMessage,true);
		helper.setTo(to);
		helper.setSubject(subject);
		helper.setText(content, true); // 标记为HTML
		helper.setFrom(from);
		mailSender.send(mimeMessage);
	}
	
	/**
	 * 发送普通文本
	 * @param to
	 * @param subject
	 * @param content
	 */
	public void sendMailText(String to,String subject,String content){
		SimpleMailMessage m = new SimpleMailMessage();
		m.setTo(to);
		m.setSubject(subject);
		m.setText(content);
		m.setFrom(from);
		mailSender.send(m);
	}
	
	/**
	 * 简单调用测试
	 */
	public void sendMail(){
		System.out.println("send mail success");
	}

}
